Learn R Programming

spconform (version 0.1.1)

plot.spconform_diagnose: Plot Diagnostic Audit for an spconform_diagnose Object

Description

Generates a multi-panel visual audit of marginal coverage, nonconformity score QQ-distribution, conditional spatial strata coverage, and boundary proximity effects.

Usage

# S3 method for spconform_diagnose
plot(x, ...)

Value

Invisibly returns the input object x.

Arguments

x

An object of class "spconform_diagnose".

...

Additional arguments passed to plotting functions.