Skip to contents

Prints a concise summary of an spconform prediction object, including the data type, target coverage level, total number of prediction points, and a preview of the first few prediction intervals.

Usage

# S3 method for class 'spconform'
print(x, ...)

Arguments

x

An object of class "spconform".

...

Further arguments passed to or from other methods.

Value

Invisibly returns the input object x.