Computes and displays summary statistics of the prediction interval widths
generated by an spconform object.
Usage
# S3 method for class 'spconform'
summary(object, ...)Computes and displays summary statistics of the prediction interval widths
generated by an spconform object.
# S3 method for class 'spconform'
summary(object, ...)