Learn R Programming

spconform (version 0.1.1)

print.spconform: Print Method for spconform Objects

Description

Displays a concise summary of the conformal prediction object including model type, nominal target coverage, and a preview table of prediction intervals.

Usage

# S3 method for spconform
print(x, ...)

Value

Invisibly returns the input object x.

Arguments

x

An object of class "spconform".

...

Further arguments passed to or from other methods.